NAME
Monitis Monitor Manager => MMM => M3
M3 is the shortened name for Monitis Monitor Manager.
This Perl module helps you manage Custom Monitors on Monitis (www.monitis.com).
SYNOPSIS
use MonitisMonitorManager;
# dry run dictates whether to upload data to Monitis - yes or no
my $dry_run = 0;
# configuration_xml is a file with the configuration XML, refer to some
# examples here: https://github.com/monitisexchange/Monitis-Linux-Scripts/tree/master/M3v3/monitis-m3/usr/local/share/monitis-m3/sample_config
my $configuration_xml = "/etc/m3.d/config.xml";
# test_config dictates whether to just test the configuration or actually
# do a proper run
my $test_config = 0;
# initialize the M3 instance
my $M3 = MonitisMonitorManager->new(
configuration_xml => $xmlfile,
dry_run => $dry_run,
test_config => $test_config);
# handle a raw command in the form of:
# 'add_monitor memory memory free:free:Bytes:2;active:active:Bytes:2'
# 'update_data memory memory free:305594368;active:879394816'
$M3->handle_raw_command($raw);
# runs just one iteration of the agents defined in the XML
$M3->invoke_agents();
# invoke the agents in a loop (using the defined interval in the XML)
$M3->invoke_agents_loop();
DESCRIPTION
For full proper documentation please refer to: https://github.com/monitisexchange/Monitis-Linux-Scripts/blob/master/M3v3/README.md
M3 Perl module comes with an init.d service. If you're using a RPM or DEB package then you're good to do, however the CPAN installation will not take care of this... Find it here: https://github.com/monitisexchange/Monitis-Linux-Scripts/tree/master/M3v3
EXPORT
MonitisMonitorManager
SEE ALSO
See also Monitis' blog with entries about M3: http://blog.monitis.com/index.php/tag/m3/
Monitis main website: http://www.monitis.com
Github repository: https://github.com/monitisexchange/Monitis-Linux-Scripts/tree/master/M3v3
AUTHOR
Dan Fruehauf, <malkodan@gmail.com>
COPYRIGHT AND LICENSE
Copyright (C) 2012 by Dan Fruehauf
This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself, either Perl version 5.14.2 or, at your option, any later version of Perl 5 you may have available.